==> HostCMS.Free_6.7.tar.gz: modules/shop/purchase/discount/coupon/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Купоны',
	'list_of_coupons' => 'Список купонов',
	'coupon' => 'Купон',
	'coupon_add' => 'Добавить',
	'not_enough_discounts' => 'Добавьте, пожалуйста, хотя бы одну скидку от суммы заказа!',
	'coupon_form_table_title_add' => 'Добавление купона',
	'coupon_form_table_title_edit' => 'Редактирование купона',
	'name' => '<acronym title="Название купона">Название</acronym>',
	'shop_purchase_discount_id' => '<acronym title="Скидка, которую предоставляет купон">Скидка</acronym>',
	'active' => '<acronym title="Активность купона">Активность</acronym>',
	'start_datetime' => "<acronym title=\"Дата начала действия купона\">Действует от</acronym>",
	'end_datetime' => "<acronym title=\"Дата окончания действия купона\">Действует до</acronym>",
	'count' => '<acronym title="Количество купонов, -1 &mdash; не ограничено">Количество</acronym>',
	'text' => '<acronym title="Код, который должен ввести покупатель для получения скидки по купону. Вы можете его заменить на текстово-числовое значение, например \'SKIDKA-2008\' или \'8 марта\'">Код купона</acronym>',
	'changeStatus_success' => "Информация успешно изменена",
	'markDeleted_success' => 'Данные о купоне успешно удалены!',
	'edit_success' => 'Купон успешно добавлен.',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'id' => 'Идентификатор',
	'import' => 'Импорт купонов',
	'import_form' => 'Файл',
	'import_result' => 'Проимпортировано %s купонов!',
	'import_error' => 'Произошла ошибка: %s',
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/purchase/discount/coupon/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2022 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Купоны',
	'list_of_coupons' => 'Список купонов',
	'coupon' => 'Купон',
	'coupon_add' => 'Добавить',
	'not_enough_discounts' => 'Добавьте, пожалуйста, хотя бы одну скидку от суммы заказа!',
	'coupon_form_table_title_add' => 'Добавление купона',
	'coupon_form_table_title_edit' => 'Редактирование купона "%s"',
	'name' => 'Название',
	'shop_purchase_discount_id' => 'Скидка',
	'active' => 'Активность',
	'start_datetime' => "Действует от",
	'end_datetime' => "Действует до",
	'count' => '<acronym title="Количество купонов, -1 &mdash; не ограничено">Количество</acronym>',
	'text' => '<acronym title="Код, который должен ввести покупатель для получения скидки по купону. Вы можете его заменить на текстово-числовое значение, например \'SKIDKA-2008\' или \'8 марта\'">Код купона</acronym>',
	'changeStatus_success' => "Информация успешно изменена",
	'markDeleted_success' => 'Данные о купоне успешно удалены!',
	'edit_success' => 'Купон успешно добавлен.',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'id' => 'Идентификатор',
	'import' => 'Импорт купонов',
	'import_form' => 'Файл',
	'import_result' => 'Проимпортировано %s купонов!',
	'import_error' => 'Произошла ошибка: %s',
	'shop_order_id' => 'Заказ',
	'apply_success' => "Информация успешно изменена.",
	'copy_success' => "Элемент успешно скопирован!",
	'sorting' => "Порядок сортировки",
	'shop_purchase_discount_coupon_dir_id' => 'Раздел',
	'root' => "Корень",
	'move_dirs_title' => "Перенос разделов и элементов",
	'move_items_dirs' => "Родительский раздел",
	'move_success' => 'Скидки перенесены',
);
